Changelog
---------

Unreleased
~~~~~~~~~~

0.0.4 (2015-09-03)
~~~~~~~~~~~~~~~~~~~

- Adds a function field to the person.
  [href]

0.0.3 (2015-08-24)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with onegov.core 0.4.25
  [href]

0.0.2 (2015-08-18)
~~~~~~~~~~~~~~~~~~~

- Renames 'academic_title' to the more general 'salutation'. This requires
  a onegov-core upgrade run to migrate existing databases.
  [href]

- Removes Gravatar support.
  [href]

0.0.1 (2015-07-03)
~~~~~~~~~~~~~~~~~~~

- Initial Release
